@@ -16,31 +16,41 @@ function StartFarabi(editorId) {
 	function displayHelp(cm) {
 		var selection = cm.getSelection();
 		if(selection) {
-			$.post('/help_search', {"topic": selection}, function(results) {
-				if(results.length > 0) {
-					humane.log("Found " + results.length + " help results for '" + selection +"'!");
-					$(".topic", $help_search_dialog).val(selection);
-					var html = '';
-					for(var i = 0; i < results.length; i++) {
-						html += '<option value="' + i + '">' + results[i].podname + "  (" + results[i].context + ")" +'</option>';
-					}
-					
-					$(".results", $help_search_dialog)
-						.html(html)
-						.change(function() {
-							var index = $(':selected', this).val();
-							$(".preview", $help_search_dialog).html(results[index].html);
-						}).change();
-					$help_search_dialog.modal('show');
-				} else {
-					humane.log("No help found for '" + selection + "'");
-				}
-			});
+			_displayHelp(selection, true);
 		} else {
-			humane.log("No selection found!");
+			_displayHelp('', true);
 		}
 	}
 
+	function _displayHelp(topic, bShowDialog) {
+		$.post('/help_search', {"topic": topic}, function(results) {
+			if(results.length > 0) {
+				humane.log("Found " + results.length + " help results for '" + topic +"'!");
+				$(".topic", $help_search_dialog).val(topic);
+				var html = '';
+				for(var i = 0; i < results.length; i++) {
+					html += '<option value="' + i + '">' + results[i].podname + "  (" + results[i].context + ")" +'</option>';
+				}
+
+				$(".results", $help_search_dialog)
+					.html(html)
+					.change(function() {
+						var index = $(':selected', this).val();
+						$(".preview", $help_search_dialog).html(results[index].html);
+					}).change().show();
+			} else {
+				humane.log("No help found for '" + topic + "'");
+
+				$(".topic", $help_search_dialog).val(topic);
+				$(".results", $help_search_dialog).html('').hide();
+				$(".preview", $help_search_dialog).html('<span class="text-error">No results found!</span>');
+			}
+			if(bShowDialog) {
+				$help_search_dialog.modal('show');
+			}
+		});
+	}
+
 	function changeMode(cm, modeFile, mode) {
 		if(typeof mode == 'undefined') {
 			mode = modeFile;
@@ -50,9 +60,6 @@ function StartFarabi(editorId) {
 		CodeMirror.autoLoadMode(cm, modeFile);	
 	}
 
-	$.get('/modes', function(modes) {
-		$("#mode_selector").html(modes);
-	});
 	$("#mode_selector").change(function() {
 		var $selectedMode = $(":selected", this);
 		humane.log("Mode changed to " + $selectedMode.html());
@@ -155,8 +162,32 @@ function StartFarabi(editorId) {
 		});
 	});
 
+	$help_search_dialog.on('hidden', function () {
+		editor.focus();
+	});
+	$perl_critic_dialog.on('hidden', function () {
+		editor.focus();
+	});
+
 	$help_search_dialog.hide();
 	$perl_critic_dialog.hide();
+
+	$(".topic").typeahead({
+		source : function(query, process) {
+			$.ajax({
+				type: 'POST',
+				url: '/typeahead',
+				async: false,
+				data: {'query': query},
+				success: function(matches) {
+					process(matches);
+				},
+				dataType: 'json',
+			});
+		}
+	}).change(function() {
+		_displayHelp($(this).val(), false);
+	});;
 }
 
 function runOnPerlito(source) {
